<?php

/**
 * helper function from cforge_broadcast_mail
 */
function cforge_broadcast_mail_broadcast(&$message, $params) {
  $node = &$params['node'];
  $sender = user_load($node->uid);
  $message['subject'] = t(
    '@site_name: @node_title',
    array(
      '@site_name' => variable_get('site_name'),
      '@node_title' => $node->title
    )
  );
  if ($node->type == 'proposition') {
    $type = $node->want ? t('Want') : t('Offer');
  }
  else {
    $type = node_type_get_type($node->type)->name;
  }
  $message['body'][] = t('@name posted a new @type.', array(
    '@name' => $sender->name,
    '@type' => $type
  ));
  $render = node_view($node);
  unset($render['comments']);
  $message['body'][] = drupal_render($render);
  if (variable_get('cforge_broadcast_optout')) {
    $account = user_load_by_mail($message['to']);
    $link = url('user/'. $account->uid. '/account/edit', array('absolute' => TRUE));
    $message['body'][] = t("Opt-out of 'broadcast' messages"). "\n". $link;
  }
  $message['headers']['From'] = $sender->mail;
  $message['headers']['Reply-to'] = $params['replytoinfoat'] ? variable_get('site_mail') : $sender->mail;

  if (isset($node->upload) && is_array($node->upload)) {
    $items = (array)reset($node->upload);
    foreach($items as $att) {
      if (!$att['fid']) {
        continue;
      }
      $file = file_load($att['fid']);
      $message['params']['attachments'][] = array(
        'uri' => $file->uri,
        'filecontent' => file_get_contents($file->uri),
        'filename' => $file->filename,
        'filemime' => file_get_mimetype($file->uri)
      );
    }
  }
}

function _cforge_broadcast_form_cforge_settings_form_alter(&$form, &$form_state) {
  $form['broadcast'] = array(
    '#title' => t('Broadcast settings'),
    '#description' => t('Emails nodes to groups of members.'),
    '#type' => 'fieldset',
    '#collapsible' => TRUE,
    'cforge_broadcast_trader_range' => array(
      '#title' => t('Trader scope'),
      '#description' => t('How far can a normal trader broadcast?'),
      '#type' => 'radios',
      '#options' => array(
        'none' => t('Traders cannot broadcast'),
        'neighbourhood' => t('Only to people in the same neighbourhood'),
        'all' => t('To all online users')
      ),
      '#default_value' => variable_get('cforge_broadcast_trader_range', 'none')
    ),
    'cforge_broadcast_optout' => array(
      '#title' => t('Allow opt-out'),
      '#description' => t('Give each user a setting to opt-out of broadcasts'),
      '#type' => 'checkbox',
      '#default_value' => variable_get('cforge_broadcast_optout', 0)
    )
  );
}


function _cforge_broadcast_form_node_form_alter(&$form, &$form_state) {
  if ($GLOBALS['user']->uid != 1) {
    $form['options'][NODE_BROADCAST_FLAG]['#access'] = FALSE;
  }
  else {
    $form['options'][NODE_BROADCAST_FLAG]['#title'] = t('Has been broadcast');
  }

  if (in_array($form['#node']->type, array('proposition', 'story', 'document', 'event' ))) {
    $form['options']['status']['#description'] = t("Uncheck this to hide this item");
    if (!$form['#node']->{NODE_BROADCAST_FLAG}) {
      $broadcast_options = array(
        '' => '--'. t('Choose').'--',
        'user_chooser_segment_me' => t('Just to me'),
        'user_chooser_segment_roles:'.RID_TRADER => t('All other active traders'),
        'user_chooser_segment_neighbourhood' => t('Everyone in my neighbourhood'),
      );
      //check if and to whom the current user can broadcast, then present the appropriate widget
      if (empty($GLOBALS['user']->roles[RID_COMMITTEE])) {
        switch (variable_get('cforge_broadcast_trader_range', 'none')) {
          case 'none': return;
          case 'all':continue;
          case 'neighbourhood':
            unset($broadcast_options['user_chooser_segment_roles:3']);
        }
      }
      $form['broadcast'] = array(
        '#title' => t('Broadcast'),
        '#description' => t('This can only be broadcast once.'),
        '#type' => 'fieldset',
        '#weight' => 100,
        'audience' => array(
          '#title' => t('Send to'),
          '#type' => 'user_chooser_many',
          '#weight' => 1,
          '#options' => $broadcast_options,
          '#required' => FALSE
        ),
        'replytoinfoat' => array(
          '#title' => t('Reply to: @mail', array('@mail' => variable_get('site_mail'))),
          '#type' => 'checkbox',
          '#access' => user_access('bypass_node_access'),//that means RID_COMMITTEE
          '#weight' => 2,
          '#required' => FALSE
        ),
        'send' => array(
          '#type' => 'submit',
          '#description' => t('Each item can be broadcast only once.'),
          '#weight' => 3,
          '#value' => t('Save & Broadcast'),
          '#submit' => array('node_broadcast_submit'),
          '#attributes' => array('onclick' => 'if(!confirm("'.t('Are you sure you want to broadcast this?').'")){return false;}'),
        ),
      );
      if (count($form['broadcast']['audience']['#options']) == 1) {
        $form['broadcast']['audience']['#value'] = key($form['broadcast']['audience']['#options']);
        $form['broadcast']['send']['#value'] = t(
          'Save & Broadcast to: @whoever',
          array('@whoever' => current($form['broadcast']['audience']['#options']))
        );
      }
      if (isset($form['image'])) {
        $form['broadcast']['#description'] .= ' '.t('Images cannot be included in broadcast mails');
      }
      $form['#validate'][] = 'node_broadcast_validate';
    }
  }
}
