<?php

/**
 * Override theme_menu_local_task().
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs.
 *
 * @ingroup themeable
 */
function sky_seldulac_menu_local_tasks() {
  $primary = menu_primary_local_tasks();
  $secondary = menu_secondary_local_tasks();
  $output = '';
  if ($primary || $secondary) {
    if ($primary) {
      $output .= "\n".'<div class="tabs-primary">'."\n".
      '  <ul>'."\n". render($primary) .'</ul>'."\n".
      '</div>';
    }
    if ($secondary) {
      $output .= "\n".'<div class="tabs-secondary">'."\n" .
      '  <ul>'."\n". render($secondary) .'</ul>'."\n" .
      '</div>';
    }
    return '<div class="tab-wrapper">' . $output .'</div>';
  }
}

/**
 * Implements hook_menu_local_action().
 */
function sky_seldulac_menu_local_action($variables) {
  $link = $variables['element']['#link'];
  $output = '<li>';
  $options = array('attributes' => array('title' => @$link['description']));
  if (isset($link['localized_options'])) {
    $options += $link['localized_options'];
  }

  if (isset($link['href'])) {
    $output .= l($link['title'], $link['href'], $options);
  }
  elseif (!empty($link['localized_options']['html'])) {
    $output .= $link['title'];
  }
  else {
    $output .= check_plain($link['title']);
  }
  $output .= "</li>\n";
  return $output;
}

function sky_seldulac_feed_icon($variables) {
  if ($image = theme('image', array('path' => 'misc/feed.png', 'width' => 16, 'height' => 16))) {
    return l(
      $image,
      $variables['url'],
      array(
        'html' => TRUE,
        'attributes' => array(
          'class' => array('feed-icon'),
          'title' => t('Get !feed-title delivered as it happens!', array('!feed-title' => $variables['title']))
        )
      )
    );
  }
}

/**
 * Theme the calendar title
 */
function sky_seldulac_date_nav_title($params) {
  $view = $params['view'];
  $date_info = $view->date_info;
  $link = !empty($params['link']) ? $params['link'] : FALSE;
  $title = date_format_date($date_info->min_date, 'custom', 'F Y');
  $granularity = 'month';
  if (!empty($date_info->mini) || $link) {
    // Month navigation titles are used as links in the mini view.
    $attributes = array('title' => t('View full page month'));
    $url = date_pager_url($view, $params['granularity'], $date_info->year . '-' . date_pad($date_info->month), TRUE);
    return l($title, $url, array('attributes' => $attributes));
  }
  else {
    return $title;
  }
}

function sky_seldulac_form_comment_form_alter(&$form, &$form_state) {   
  $form['comment_body']['und']['0']['#title'] = t('Comment');
}



function sky_seldulac_form_node_form_alter(&$form, &$form_state) {
  if ($form['#node']->type == 'page') {
    //flatten the menu, so you can only put things at the top level
    foreach ($form['menu']['link']['parent']['#options'] as $key => $linkname) {
      if (substr($linkname, 0, 2) == '--') {
        unset($form['menu']['link']['parent']['#options'][$key]);
      }
    }
    $form['menu']['link']['parent']['#title'] = t('Put in menu');

    $form['menu']['enabled']['#default_value'] = TRUE;
    $form['menu']['link']['link_title']['#required'] = TRUE;
  }
  else {
    unset($form['menu']);
  }
}

